BalanceCascadeClassifier
==================================================================================

.. currentmodule:: imbalanced_ensemble.ensemble.under_sampling

.. autoclass:: BalanceCascadeClassifier

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~BalanceCascadeClassifier.fit
      
      
        ~BalanceCascadeClassifier.get_params
      
      
        ~BalanceCascadeClassifier.predict
      
      
        ~BalanceCascadeClassifier.predict_proba
      
      
        ~BalanceCascadeClassifier.score
      
      
        ~BalanceCascadeClassifier.set_params
      
   
   

.. include:: ../../../back_references/imbalanced_ensemble.ensemble.under_sampling.BalanceCascadeClassifier.examples

.. raw:: html

    <div style='clear:both'></div>